/*---------------------------------------------------------
 *
 * Name:        CONTEST.C
 *
 * Purpose:     Simple Contest Assistant for use with Pasokon TV 3.1.
 *
 * Description: Given the call of the other station, this generates
 *              text commands to place that call, a sequence number
 *              and your call on an image.
 *              A log file is also kept with date, time, and
 *              optional comment.
 *
 * Usage:       First add something like this to the PKTV.CFG
 *              file.  It must be all on one long line but is
 *              shown on multiple lines here:
 *
 *                      RUN_MENU "Contest..." C
 *                          PROMPT="Enter call of other station"
 *                          PROMPT="Comment"
 *                          RUN="CONTEST %1 %2"
 *                          OPEN="CONTEST.BMP"
 *                          TEXT_FROM=CONTEST.CMD
 *                          DELETE=CONTEST.CMD
 *
 * Files used:  CONTEST.EXE     - Executable program.
 *              CONTEST.SEQ     - Next available sequence number.
 *              CONTEST.LOG     - Log file.
 *              CONTEST.BMP     - A background picture.
 *              CONTEST.CMD     - Temporary text commands.
 *
 *--------------------------------------------------------*/


#include <stdio.h>
#include <string.h>
#include <time.h>

void main (int argc, char *argv[])
{
        char other_call[30];
        char my_call[30];
        char comment[60];
        FILE *fp;
        int seq_no;
        char *p;
        char stemp[200];


/*
 * Get call for other station and me from command line.
 */
        if (argc >= 2)
            strcpy (other_call, argv[1]);
        else
            strcpy (other_call, "who???");

/*
 * Get optional comment from command line.
 */
        if (argc >= 3)
            strcpy (comment, argv[2]);
        else
            strcpy (comment, "");

/*
 * Find my call by looking in the PKTV.CFG file.
 */
        strcpy (my_call, "me???");
        fp = fopen ("PKTV.CFG", "r");
        if (fp == NULL)
            fp = fopen ("EZSSTV.CFG", "r");
        if (fp != NULL) {

            while (fgets(stemp, sizeof(stemp), fp) != NULL) {
                p = strtok (stemp, " \t\n");
                if (p != NULL && stricmp(p, "CALL") == 0) {
                    p = strtok (NULL, " \t\n");
                    if (p != NULL)
                        strcpy (my_call, p);
                }
            }
            fclose (fp);
        }

/*
 * Get next available sequence number from CONTEST.SEQ file.
 * If not there, start with number 1.
 * Put next available sequence number in file.
 */
        seq_no = 1;

        fp = fopen ("CONTEST.SEQ", "r");
        if (fp != NULL) {
            fgets (stemp, sizeof(stemp), fp);
            seq_no = atoi (stemp);
            fclose (fp);
        }

        fp = fopen ("CONTEST.SEQ", "w");
        if (fp != NULL) {
            fprintf (fp, "%d\n", seq_no+1);
            fclose (fp);
        }

/*
 * Create text command file for use by TEXT_FROM option in
 * the RUN_MENU command in PKTV.CFG.
 *
 * These commands are explained in the help file RUN.TXT.
 */
        
        fp = fopen("CONTEST.CMD", "w");

        if (fp != NULL) {
            fprintf (fp, "FONT Lucid\n");
            fprintf (fp, "SIZE 2\n");
            fprintf (fp, "BORDER 1\n");
            fprintf (fp, "COLOR 255 255 0\n");
            fprintf (fp, "COLOR2 255 0 0\n");
            fprintf (fp, "GRADIENT 1\n");

            fprintf (fp, "X 10\n");
            fprintf (fp, "Y 60\n");
            fprintf (fp, "%s # %d\n", other_call, seq_no);

            fprintf (fp, "COLOR 0 255 0\n");
            fprintf (fp, "GRADIENT 0\n");

            fprintf (fp, "X 10\n");
            fprintf (fp, "Y 440\n");
            fprintf (fp, "de %s\n", my_call);

            fclose (fp);
        }

/*
 * Add date, time, sequence number, call, comment to log file.
 * If you have a suitably equipped transceiver this could
 * be modified to ask transceiver for current frequency.
 */
        fp = fopen ("CONTEST.LOG", "a");
        if (fp != NULL) {
            time_t now;
            char date_time[30];

            time (&now);
            strftime (date_time, sizeof(date_time), "%x %H:%M", gmtime(&now));
            fprintf (fp, "%s  #%d  %s  %s\n", date_time, seq_no, other_call, comment); 
            fclose (fp);
        }

        exit (0);
}
